==> moyoung_ble_plugin-1.0.32.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/DeviceBatteryHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPDeviceBatteryListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.DeviceBatteryBean;

import io.flutter.plugin.common.MethodCall;

public class DeviceBatteryHandler extends BaseConnectionEventChannelHandler {
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setDeviceBatteryListener(new CRPDeviceBatteryListener() {
            @Override
            public void onSubscribe(boolean subscribe) {
                if (eventSink == null) {
                    return;
                }
                DeviceBatteryBean device = new DeviceBatteryBean(DeviceBatteryBean.SUBSCRIBE);
                device.setSubscribe(subscribe);
                String jsonStr = GsonUtils.get().toJson(device, DeviceBatteryBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onDeviceBattery(int deviceBattery) {
                if (eventSink == null) {
                    return;
                }
                DeviceBatteryBean device = new DeviceBatteryBean(DeviceBatteryBean.DEVICEBATTERY);
                device.setDeviceBattery(deviceBattery);
                String jsonStr = GsonUtils.get().toJson(device, DeviceBatteryBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }
        });
    }

}

==> moyoung_ble_plugin-1.0.62.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/DeviceBatteryHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.os.Handler;
import android.os.Looper;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPDeviceBatteryListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.DeviceBatteryBean;

import io.flutter.plugin.common.MethodCall;

public class DeviceBatteryHandler extends BaseConnectionEventChannelHandler {
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setDeviceBatteryListener(new CRPDeviceBatteryListener() {
            @Override
            public void onSubscribe(boolean subscribe) {
                if (eventSink == null) {
                    return;
                }
                DeviceBatteryBean device = new DeviceBatteryBean(DeviceBatteryBean.SUBSCRIBE);
                device.setSubscribe(subscribe);
                String jsonStr = GsonUtils.get().toJson(device, DeviceBatteryBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onDeviceBattery(int deviceBattery) {
                if (eventSink == null) {
                    return;
                }
                DeviceBatteryBean device = new DeviceBatteryBean(DeviceBatteryBean.DEVICEBATTERY);
                device.setDeviceBattery(deviceBattery);
                String jsonStr = GsonUtils.get().toJson(device, DeviceBatteryBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
            }
        });
    }

}
